@@ -80,7 +80,7 @@ where
     /// assert_eq!([1.0, 2.0, 0.0, 0.0], vector[..]);
     /// let mut vector = vec!(Complex::new(1.0, 2.0)).to_complex_time_vec();
     /// vector.zero_pad(2, PaddingOption::End).expect("Ignoring error handling in examples");
-    /// assert_eq!([1.0, 2.0, 0.0, 0.0], vector[..]);
+    /// assert_eq!([Complex::new(1.0, 2.0), Complex::new(0.0, 0.0)], vector[..]);
     /// ```
     fn zero_pad(&mut self, points: usize, option: PaddingOption) -> VoidResult;
 
@@ -101,7 +101,7 @@ where
     /// assert_eq!([1.0, 0.0, 2.0, 0.0], vector[..]);
     /// let mut vector = vec!(Complex::new(1.0, 2.0), Complex::new(3.0, 4.0)).to_complex_time_vec();
     /// vector.zero_interleave(2).expect("Ignoring error handling in examples");
-    /// assert_eq!([1.0, 2.0, 0.0, 0.0, 3.0, 4.0, 0.0, 0.0], vector[..]);
+    /// assert_eq!([Complex::new(1.0, 2.0), Complex::new(0.0, 0.0), Complex::new(3.0, 4.0), Complex::new(0.0, 0.0)], vector[..]);
     /// ```
     fn zero_interleave(&mut self, factor: u32) -> VoidResult;
 }
@@ -135,7 +135,7 @@ where
     /// assert_eq!([1.0, 2.0, 0.0, 0.0], vector[..]);
     /// let mut vector = vec!(Complex::new(1.0, 2.0)).to_complex_time_vec();
     /// vector.zero_pad_b(&mut buffer, 2, PaddingOption::End).expect("Ignoring error handling in examples");
-    /// assert_eq!([1.0, 2.0, 0.0, 0.0], vector[..]);
+    /// assert_eq!([Complex::new(1.0, 2.0), Complex::new(0.0, 0.0)], vector[..]);
     /// ```
     fn zero_pad_b<B>(&mut self, buffer: &mut B, points: usize, option: PaddingOption) -> VoidResult
     where
@@ -159,7 +159,7 @@ where
     /// assert_eq!([1.0, 0.0, 2.0, 0.0], vector[..]);
     /// let mut vector = vec!(Complex::new(1.0, 2.0), Complex::new(3.0, 4.0)).to_complex_time_vec();
     /// vector.zero_interleave_b(&mut buffer, 2);
-    /// assert_eq!([1.0, 2.0, 0.0, 0.0, 3.0, 4.0, 0.0, 0.0], vector[..]);
+    /// assert_eq!([Complex::new(1.0, 2.0), Complex::new(0.0, 0.0), Complex::new(3.0, 4.0), Complex::new(0.0, 0.0)], vector[..]);
     /// ```
     fn zero_interleave_b<B>(&mut self, buffer: &mut B, factor: u32)
     where
@@ -316,7 +316,7 @@ where
             return Err(ErrorReason::InvalidArgumentLength);
         }
 
-        r#try!(self.resize(len));
+        self.resize(len)?;
         let data = self.data.to_slice_mut();
         match option {
             PaddingOption::End => {
@@ -368,7 +368,7 @@ where
             return Ok(());
         }
 
-        r#try!(self.resize(len));
+        self.resize(len)?;
 
         if is_complex {
             let data = self.data.to_slice_mut();
@@ -489,7 +489,7 @@ where
         }
 
         for t in targets.iter_mut() {
-            r#try!(t.resize(data_length / num_targets));
+            t.resize(data_length / num_targets)?;
         }
 
         let data = &self.data.to_slice();
@@ -532,7 +532,7 @@ where
                 }
             }
 
-            r#try!(self.resize(sources[0].len() * num_sources));
+            self.resize(sources[0].len() * num_sources)?;
 
             let data_length = self.len();
             let is_complex = self.is_complex();
@@ -565,7 +565,7 @@ mod tests {
     fn swap_halves_real_even_test() {
         let mut v = vec![1.0, 2.0, 3.0, 4.0].to_real_time_vec();
         v.swap_halves();
-        assert_eq!(&v[..], &[3.0, 4.0, 1.0, 2.0]);
+        assert_eq!(v.data(..), &[3.0, 4.0, 1.0, 2.0]);
     }
 
     #[test]
@@ -574,7 +574,7 @@ mod tests {
             vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0].to_real_time_vec();
         v.swap_halves();
         assert_eq!(
-            &v[..],
+            v.data(..),
             &[7.0, 8.0, 9.0, 10.0, 11.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0]
         );
     }
@@ -583,14 +583,14 @@ mod tests {
     fn swap_halves_complex_even_test() {
         let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0].to_complex_time_vec();
         v.swap_halves();
-        assert_eq!(&v[..], &[5.0, 6.0, 7.0, 8.0, 1.0, 2.0, 3.0, 4.0]);
+        assert_eq!(v.data(..), &[5.0, 6.0, 7.0, 8.0, 1.0, 2.0, 3.0, 4.0]);
     }
 
     #[test]
     fn swap_halves_complex_odd_test() {
         let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0].to_complex_time_vec();
         v.swap_halves();
-        assert_eq!(&v[..], &[7.0, 8.0, 9.0, 10.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0]);
+        assert_eq!(v.data(..), &[7.0, 8.0, 9.0, 10.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0]);
     }
 
     #[test]
@@ -601,7 +601,7 @@ mod tests {
             1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
             0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -612,7 +612,7 @@ mod tests {
             0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 0.0,
             0.0, 0.0, 0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -623,7 +623,7 @@ mod tests {
             1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.0,
             8.0, 9.0, 10.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -636,7 +636,7 @@ mod tests {
             1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.0,
             8.0, 9.0, 10.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -650,7 +650,7 @@ mod tests {
             0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 0.0,
             0.0, 0.0, 0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -662,7 +662,7 @@ mod tests {
             1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
             0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -675,7 +675,7 @@ mod tests {
             0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 0.0,
             0.0, 0.0, 0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -691,7 +691,7 @@ mod tests {
             0.0, 0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 0.0,
             0.0, 0.0, 0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -717,7 +717,7 @@ mod tests {
             1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
             0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -727,7 +727,7 @@ mod tests {
         let expected = [
             0.0, 0.0, 0.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 0.0, 0.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
@@ -737,21 +737,21 @@ mod tests {
         let expected = [
             1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 7.0, 8.0, 9.0, 10.0,
         ];
-        assert_eq!(&v[..], &expected);
+        assert_eq!(v.data(..), &expected);
     }
 
     #[test]
     fn zero_interleave_test() {
         let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0].to_real_time_vec();
         v.zero_interleave(2).unwrap();
-        assert_eq!(&v[..], &[1.0, 0.0, 2.0, 0.0, 3.0, 0.0, 4.0, 0.0, 5.0, 0.0]);
+        assert_eq!(v.data(..), &[1.0, 0.0, 2.0, 0.0, 3.0, 0.0, 4.0, 0.0, 5.0, 0.0]);
     }
 
     #[test]
     fn zero_interleave_even_test() {
         let mut v = vec![1.0, 2.0, 3.0, 4.0].to_real_time_vec();
         v.zero_interleave(2).unwrap();
-        assert_eq!(&v[..], &[1.0, 0.0, 2.0, 0.0, 3.0, 0.0, 4.0, 0.0]);
+        assert_eq!(v.data(..), &[1.0, 0.0, 2.0, 0.0, 3.0, 0.0, 4.0, 0.0]);
     }
 
     #[test]
@@ -759,14 +759,14 @@ mod tests {
         let mut v = vec![1.0, 2.0, 3.0, 4.0, 5.0].to_real_time_vec();
         let mut buffer = SingleBuffer::new();
         v.zero_interleave_b(&mut buffer, 2);
-        assert_eq!(&v[..], &[1.0, 0.0, 2.0, 0.0, 3.0, 0.0, 4.0, 0.0, 5.0, 0.0]);
+        assert_eq!(v.data(..), &[1.0, 0.0, 2.0, 0.0, 3.0, 0.0, 4.0, 0.0, 5.0, 0.0]);
     }
 
     #[test]
     fn zero_interleave_complex_test() {
         let mut v = vec![1.0, 2.0, 3.0, 4.0].to_complex_time_vec();
         v.zero_interleave(2).unwrap();
-        assert_eq!(&v[..], &[1.0, 2.0, 0.0, 0.0, 3.0, 4.0, 0.0, 0.0]);
+        assert_eq!(v.data(..), &[1.0, 2.0, 0.0, 0.0, 3.0, 4.0, 0.0, 0.0]);
     }
 
     #[test]
@@ -774,6 +774,6 @@ mod tests {
         let mut v = vec![1.0, 2.0, 3.0, 4.0].to_complex_time_vec();
         let mut buffer = SingleBuffer::new();
         v.zero_interleave_b(&mut buffer, 2);
-        assert_eq!(&v[..], &[1.0, 2.0, 0.0, 0.0, 3.0, 4.0, 0.0, 0.0]);
+        assert_eq!(v.data(..), &[1.0, 2.0, 0.0, 0.0, 3.0, 4.0, 0.0, 0.0]);
     }
 }
