@@ -1,13 +1,12 @@
 use super::super::{
     ComplexNumberSpace, Domain, DspVec, ErrorReason, GetMetaData, MetaData, NumberSpace, PosEq,
-    RealNumberSpace, ScalarResult, ToSlice, Vector,
+    RealNumberSpace, ScalarResult, ToSlice, Vector
 };
 use super::kahan_sum;
 use crate::array_to_complex;
 use crate::multicore_support::*;
 use crate::numbers::*;
 use crate::simd_extensions::*;
-use std::ops::*;
 
 /// An operation which multiplies each vector element with a constant
 pub trait DotProductOps<A, R, T, N, D>
@@ -71,7 +70,7 @@ where
         factor: &O,
     ) -> ScalarResult<T>
     where
-        O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+        O: Vector<T> + GetMetaData<T, NO, DO>,
         NO: NumberSpace,
         DO: Domain,
     {
@@ -82,7 +81,7 @@ where
         let data_length = self.len();
         let array = self.data.to_slice();
         let partition = Reg::calc_data_alignment_reqs(&array[0..data_length]);
-        let other = &factor[..];
+        let other = factor.data(..);
         let chunks = Chunk::get_zipped(
             Complexity::Small,
             &self.multicore_settings,
@@ -118,7 +117,7 @@ where
         factor: &O,
     ) -> ScalarResult<Complex<T>>
     where
-        O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+        O: Vector<T> + GetMetaData<T, NO, DO>,
         NO: NumberSpace,
         DO: Domain,
     {
@@ -133,7 +132,7 @@ where
         let data_length = self.len();
         let array = self.data.to_slice();
         let partition = Reg::calc_data_alignment_reqs(&array[0..data_length]);
-        let other = &factor[..];
+        let other = factor.data(..);
         let chunks = Chunk::get_zipped(
             Complexity::Small,
             &self.multicore_settings,
@@ -170,7 +169,7 @@ where
         factor: &O,
     ) -> ScalarResult<T>
     where
-        O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+        O: Vector<T> + GetMetaData<T, NO, DO>,
         NO: NumberSpace,
         DO: Domain,
     {
@@ -181,7 +180,7 @@ where
         let data_length = self.len();
         let array = self.data.to_slice();
         let partition = Reg::calc_data_alignment_reqs(&array[0..data_length]);
-        let other = &factor[..];
+        let other = factor.data(..);
         let chunks = Chunk::get_zipped(
             Complexity::Small,
             &self.multicore_settings,
@@ -216,7 +215,7 @@ where
         factor: &O,
     ) -> ScalarResult<Complex<T>>
     where
-        O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+        O: Vector<T> + GetMetaData<T, NO, DO>,
         NO: NumberSpace,
         DO: Domain,
     {
@@ -231,7 +230,7 @@ where
         let data_length = self.len();
         let array = self.data.to_slice();
         let partition = Reg::calc_data_alignment_reqs(&array[0..data_length]);
-        let other = &factor[..];
+        let other = factor.data(..);
         let chunks = Chunk::get_zipped(
             Complexity::Small,
             &self.multicore_settings,
@@ -269,7 +268,7 @@ where
     T: RealNumber,
     N: RealNumberSpace,
     D: Domain,
-    O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+    O: Vector<T> + GetMetaData<T, NO, DO>,
     NO: PosEq<N> + NumberSpace,
     DO: PosEq<D> + Domain,
 {
@@ -286,7 +285,7 @@ where
     T: RealNumber,
     N: ComplexNumberSpace,
     D: Domain,
-    O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+    O: Vector<T> + GetMetaData<T, NO, DO>,
     NO: PosEq<N> + NumberSpace,
     DO: PosEq<D> + Domain,
 {
@@ -303,7 +302,7 @@ where
     T: RealNumber,
     N: RealNumberSpace,
     D: Domain,
-    O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+    O: Vector<T> + GetMetaData<T, NO, DO>,
     NO: PosEq<N> + NumberSpace,
     DO: PosEq<D> + Domain,
 {
@@ -320,7 +319,7 @@ where
     T: RealNumber,
     N: ComplexNumberSpace,
     D: Domain,
-    O: Vector<T> + GetMetaData<T, NO, DO> + Index<RangeFull, Output = [T]>,
+    O: Vector<T> + GetMetaData<T, NO, DO>,
     NO: PosEq<N> + NumberSpace,
     DO: PosEq<D> + Domain,
 {
