@@ -3,10 +3,32 @@ use super::super::{
     FrequencyDomain, FrequencyDomainOperations, FrequencyToTimeDomainOperations, GetMetaData,
     InsertZerosOpsBuffered, MetaData, NoTradeBuffer, NumberSpace, PaddingOption, PosEq,
     ReorganizeDataOps, ScaleOps, TimeDomain, TimeToFrequencyDomainOperations, ToComplexVector,
-    ToFreqResult, ToSliceMut, Vector, VoidResult,
+    ToFreqResult, ToSliceMut, Vector, VoidResult, FloatIndexMut
 };
 use crate::numbers::*;
-use std::ops::*;
+
+/// This trait allows to transform an argument so that it can be used for cross correlation. Refer to the description of
+/// `CrossCorrelationOps` for more details.
+pub trait CrossCorrelationArgumentOps<S, T>: ToFreqResult
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+{
+    /// Prepares an argument to be used for convolution. Preparing an argument includes two steps:
+    ///
+    /// 1. Calculate the plain FFT
+    /// 2. Calculate the complex conjugate
+    fn prepare_argument<B>(self, buffer: &mut B) -> Self::FreqResult
+    where
+        B: for<'a> Buffer<'a, S, T>;
+
+    /// Prepares an argument to be used for convolution. The argument is zero padded to
+    /// length of `2 * self.points() - 1`
+    /// and then the same operations are performed as described for `prepare_argument`.
+    fn prepare_argument_padded<B>(self, buffer: &mut B) -> Self::FreqResult
+    where
+        B: for<'a> Buffer<'a, S, T>;
+}
 
 /// Cross-correlation of data vectors. See also https://en.wikipedia.org/wiki/Cross-correlation
 ///
@@ -33,9 +55,9 @@ use std::ops::*;
 /// let mut buffer = SingleBuffer::new();
 /// let argument = argument.prepare_argument_padded(&mut buffer);
 /// vector.correlate(&mut buffer, &argument).expect("Ignoring error handling in examples");
-/// let expected = &[2.0, 0.0, 8.0, 0.0, 20.0, 0.0, 24.0, 0.0, 18.0, 0.0];
+/// let expected = &[Complex::new(2.0, 0.0), Complex::new(8.0, 0.0), Complex::new(20.0, 0.0), Complex::new(24.0, 0.0), Complex::new(18.0, 0.0)];
 /// for i in 0..vector.len() {
-///     assert!(f32::abs(vector[i] - expected[i]) < 1e-4);
+///     assert!((vector[i] - expected[i]).norm() < 1e-4);
 /// }
 /// ```
 /// # Failures
@@ -44,28 +66,6 @@ use std::ops::*;
 /// 1. `VectorMustBeComplex`: if `self` is in real number space.
 /// 3. `VectorMetaDataMustAgree`: in case `self` and `function` are not
 ///    in the same number space and same domain.
-pub trait CrossCorrelationArgumentOps<S, T>: ToFreqResult
-where
-    S: ToSliceMut<T>,
-    T: RealNumber,
-{
-    /// Prepares an argument to be used for convolution. Preparing an argument includes two steps:
-    ///
-    /// 1. Calculate the plain FFT
-    /// 2. Calculate the complex conjugate
-    fn prepare_argument<B>(self, buffer: &mut B) -> Self::FreqResult
-    where
-        B: for<'a> Buffer<'a, S, T>;
-
-    /// Prepares an argument to be used for convolution. The argument is zero padded to
-    /// length of `2 * self.points() - 1`
-    /// and then the same operations are performed as described for `prepare_argument`.
-    fn prepare_argument_padded<B>(self, buffer: &mut B) -> Self::FreqResult
-    where
-        B: for<'a> Buffer<'a, S, T>;
-}
-
-/// A trait to calculate the cross correlation.
 pub trait CrossCorrelationOps<A, S, T, N, D>
 where
     S: ToSliceMut<T>,
@@ -125,7 +125,7 @@ where
     N: ComplexNumberSpace,
     D: TimeDomain,
     DF: FrequencyDomain,
-    O: Vector<T> + GetMetaData<T, NO, DF> + Index<RangeFull, Output = [T]>,
+    O: Vector<T> + GetMetaData<T, NO, DF>,
     NO: PosEq<N> + NumberSpace,
 {
     fn correlate<B>(&mut self, buffer: &mut B, other: &O) -> VoidResult
@@ -147,22 +147,22 @@ where
         }
 
         let points = other.points();
-        r#try!(self.zero_pad_b(buffer, points, PaddingOption::Surround));
+        self.zero_pad_b(buffer, points, PaddingOption::Surround)?;
         let len = self.len();
         let mut temp = buffer.borrow(len);
         // The next steps: fft, mul, ifft
         // However to keep the impl definition simpler and to avoid unnecessary copies
         // we have to to be creative with where we store our signal and what's the buffer.
         {
-            let complex = (&mut self[..]).to_complex_time_vec();
+            let complex = (self.data_mut(..)).to_complex_time_vec();
             let mut buffer = NoTradeBuffer::new(&mut temp[..]);
             complex.plain_fft(&mut buffer); // after this operation, our result is in `temp`. See also definition of `NoTradeBuffer`.
         }
         {
-            let other = (&other[..]).to_complex_freq_vec();
+            let other = (other.data(..)).to_complex_freq_vec();
             let mut complex = (&mut temp[..]).to_complex_freq_vec();
-            r#try!(complex.mul(&other));
-            let mut buffer = NoTradeBuffer::new(&mut self[..]);
+            complex.mul(&other)?;
+            let mut buffer = NoTradeBuffer::new(self.data_mut(..));
             complex.plain_ifft(&mut buffer); // the result is now back in `self`.
         }
         let p = self.points();
@@ -197,7 +197,7 @@ mod tests {
         let mut buffer = SingleBuffer::new();
         let b = b.prepare_argument_padded(&mut buffer);
         a.correlate(&mut buffer, &b).unwrap();
-        let res = &a[..];
+        let res = a.data(..);
         let tol = 0.1;
         for i in 0..c.len() {
             if (res[i] - c[i]).abs() > tol {
@@ -214,7 +214,7 @@ mod tests {
         let mut buffer = SingleBuffer::new();
         let b = b.prepare_argument_padded(&mut buffer);
         a.correlate(&mut buffer, &b).unwrap();
-        let res = &a[..];
+        let res = a.data(..);
         let tol = 0.1;
         for i in 0..c.len() {
             if (res[i] - c[i]).abs() > tol {
