@@ -1,7 +1,7 @@
 use super::super::{
     Buffer, ComplexNumberSpace, DataDomain, DspVec, ErrorReason, FrequencyDomain,
     FrequencyDomainOperations, InsertZerosOpsBuffered, MetaData, RededicateForceOps, ScaleOps,
-    TimeDomainOperations, ToRealTimeResult, ToSliceMut, ToTimeResult, TransRes, Vector,
+    TimeDomainOperations, ToRealTimeResult, ToSliceMut, ToTimeResult, TransRes, Vector, FloatIndex
 };
 use super::fft;
 use crate::multicore_support::*;
@@ -32,10 +32,10 @@ where
     /// let mut buffer = SingleBuffer::new();
     /// let result = vector.plain_ifft(&mut buffer);
     /// let actual = &result[..];
-    /// let expected = &[1.0, 0.0, -0.5, 0.8660254, -0.5, -0.8660254];
+    /// let expected = &[Complex::new(1.0, 0.0), Complex::new(-0.5, 0.8660254), Complex::new(-0.5, -0.8660254)];
     /// assert_eq!(actual.len(), expected.len());
     /// for i in 0..actual.len() {
-    ///        assert!(f32::abs(actual[i] - expected[i]) < 1e-4);
+    ///        assert!((actual[i] - expected[i]).norm() < 1e-4);
     /// }
     /// ```
     fn plain_ifft<B>(self, buffer: &mut B) -> Self::TimeResult
@@ -54,10 +54,10 @@ where
     /// let mut buffer = SingleBuffer::new();
     /// let result = vector.ifft(&mut buffer);
     /// let actual = &result[..];
-    /// let expected = &[1.0, 0.0, -0.5, 0.8660254, -0.5, -0.8660254];
+    /// let expected = &[Complex::new(1.0, 0.0), Complex::new(-0.5, 0.8660254), Complex::new(-0.5, -0.8660254)];
     /// assert_eq!(actual.len(), expected.len());
     /// for i in 0..actual.len() {
-    ///        assert!(f32::abs(actual[i] - expected[i]) < 1e-4);
+    ///        assert!((actual[i] - expected[i]).norm() < 1e-4);
     /// }
     /// ```
     fn ifft<B>(self, buffer: &mut B) -> Self::TimeResult
@@ -200,7 +200,7 @@ where
             ));
         }
 
-        if self.points() > 0 && self[1].abs() > T::from(1e-10).unwrap() {
+        if self.points() > 0 && self.data(1).abs() > T::from(1e-10).unwrap() {
             self.mark_vector_as_invalid();
             self.number_space.to_complex();
             self.domain.to_freq();
@@ -240,7 +240,7 @@ where
     where
         B: for<'a> Buffer<'a, S, T>,
     {
-        let mut result = r#try!(self.sifft(buffer));
+        let mut result = self.sifft(buffer)?;
         result.unapply_window(window);
         Ok(result)
     }
