@@ -17,7 +17,7 @@ pub use self::real_interpolation::*;
 
 use super::{
     Buffer, BufferBorrow, Domain, DspVec, ErrorReason, GetMetaData, MetaData, NumberSpace,
-    ToSliceMut, Vector, VoidResult,
+    ToSliceMut, Vector, VoidResult
 };
 use crate::gpu_support::GpuSupport;
 use crate::inline_vector::InlineVector;
@@ -83,15 +83,13 @@ fn create_shifted_copies<O, T: RealNumber, Reg: SimdGeneric<T>>(
     vec: &O,
 ) -> InlineVector<InlineVector<Reg>>
 where
-    O: Vector<T> + Index<RangeFull, Output = [T]>,
+    O: Vector<T>,
 {
     let step = if vec.is_complex() { 2 } else { 1 };
     let number_of_shifts = Reg::LEN / step;
     let mut shifted_copies = InlineVector::with_capacity(number_of_shifts);
     let mut i = 0;
-    let len = vec.len();
-    let data = &vec[..];
-    let data = &data[0..len];
+    let data = vec.data(..);
     while i < number_of_shifts {
         let mut data = data.iter().rev();
 
@@ -224,7 +222,7 @@ where
         vector: &O,
         range: Range<usize>,
     ) where
-        O: Vector<T> + Index<RangeFull, Output = [T]> + GetMetaData<T, NO, DO>,
+        O: Vector<T> + GetMetaData<T, NO, DO>,
         NO: NumberSpace,
         DO: Domain,
     {
@@ -244,7 +242,7 @@ where
         };
         let len = self.len();
         if self.is_complex() {
-            let other = &vector[..];
+            let other = vector.data(..);
             let data = self.data.to_slice();
             let other = array_to_complex(&other[0..vector.len()]);
             let complex = array_to_complex(&data[0..len]);
@@ -261,7 +259,7 @@ where
                 );
             }
         } else {
-            let other = &vector[..];
+            let other = vector.data(..);
             let data = self.data.to_slice();
             let other = &other[0..vector.len()];
             let data = &data[0..len];
@@ -278,7 +276,7 @@ where
     fn convolve_signal_scalar<B, O, NO, DO>(&mut self, buffer: &mut B, vector: &O)
     where
         B: for<'a> Buffer<'a, S, T>,
-        O: Vector<T> + Index<RangeFull, Output = [T]> + GetMetaData<T, NO, DO>,
+        O: Vector<T> + GetMetaData<T, NO, DO>,
         NO: NumberSpace,
         DO: Domain,
     {
@@ -300,7 +298,7 @@ where
             let len = self.len();
             let mut temp = buffer.borrow(len);
             {
-                let other = &vector[..];
+                let other = vector.data(..);
                 let data = self.data.to_slice();
                 let temp = temp.to_slice_mut();
                 let other = array_to_complex(&other[0..vector.len()]);
@@ -332,7 +330,7 @@ where
             let len = self.len();
             let mut temp = buffer.borrow(len);
             {
-                let other = &vector[..];
+                let other = vector.data(..);
                 let data = self.data.to_slice();
                 let temp = temp.to_slice_mut();
                 let other = &other[0..vector.len()];
@@ -505,7 +503,7 @@ where
         vector: &O,
     ) where
         B: for<'a> Buffer<'a, S, T>,
-        O: Vector<T> + Index<RangeFull, Output = [T]>,
+        O: Vector<T>,
     {
         if self.is_complex() {
             self.convolve_signal_simd_impl::<Reg, _, _, _, _, _, _, _>(
@@ -541,7 +539,7 @@ where
         simd_sum: RSum,
     ) where
         B: for<'a> Buffer<'a, S, T>,
-        O: Vector<T> + Index<RangeFull, Output = [T]>,
+        O: Vector<T>,
         TT: Zero + Clone + Copy + Add<Output = TT> + Mul<Output = TT> + Send + Sync,
         C: Fn(&[T]) -> &[TT],
         CMut: Fn(&mut [T]) -> &mut [TT],
@@ -556,7 +554,7 @@ where
         let len = self.len();
         let mut temp = buffer.borrow(len);
         {
-            let other = &vector[..];
+            let other = vector.data(..);
             let data = self.data.to_slice();
             let temp = temp.to_slice_mut();
             let points = self.points();
