@@ -1,12 +1,39 @@
 //! This module defines the basic vector trait and indexers.
 use super::{
     Buffer, BufferBorrow, ComplexNumberSpace, DataDomain, Domain, DspVec, ErrorReason, NumberSpace,
-    ToSlice, ToSliceMut, TypeMetaData, VoidResult,
+    ToSlice, ToSliceMut, TypeMetaData, VoidResult
 };
 use crate::multicore_support::MultiCoreSettings;
 use crate::numbers::*;
 use std::ops::*;
 use crate::{array_to_complex, array_to_complex_mut};
+use super::meta::Real as RealSpace;
+use super::meta::Complex as ComplexSpace;
+
+/// Like [`std::ops::Index`](https://doc.rust-lang.org/std/ops/trait.Index.html)
+/// but with a different method name so that it can be used to implement an additional range
+/// accessor for float data.
+pub trait FloatIndex<Idx>
+where
+    Idx: Sized,
+{
+    type Output: ?Sized;
+    /// The method for float indexing. If the vector is real valued then this function just returns the values
+    // in the vector. If the vector is compled valued then will returned real and imaginary values interleaved (all
+    // values at even indexes are the real parts, while all values at odd indexes are imag parts).
+    fn data(&self, index: Idx) -> &Self::Output;
+}
+
+/// Like [`std::ops::IndexMut`](https://doc.rust-lang.org/std/ops/trait.IndexMut.html)
+/// but with a different method name so that it can be used to implement a additional range
+/// accessor for float data.
+pub trait FloatIndexMut<Idx>: FloatIndex<Idx>
+where
+    Idx: Sized,
+{
+    /// The method for real indexing
+    fn data_mut(&mut self, index: Idx) -> &mut Self::Output;
+}
 
 /// Like [`std::ops::Index`](https://doc.rust-lang.org/std/ops/trait.Index.html)
 /// but with a different method name so that it can be used to implement an additional range
@@ -19,7 +46,7 @@ where
 {
     type Output: ?Sized;
     /// The method for complex indexing
-    fn complex(&self, index: Idx) -> &Self::Output;
+    fn datac(&self, index: Idx) -> &Self::Output;
 }
 
 /// Like [`std::ops::IndexMut`](https://doc.rust-lang.org/std/ops/trait.IndexMut.html)
@@ -32,7 +59,7 @@ where
     Idx: Sized,
 {
     /// The method for complex indexing
-    fn complex_mut(&mut self, index: Idx) -> &mut Self::Output;
+    fn datac_mut(&mut self, index: Idx) -> &mut Self::Output;
 }
 
 /// A trait which provides information about number space and domain.
@@ -71,6 +98,8 @@ pub trait ResizeBufferedOps<S: ToSliceMut<T>, T: RealNumber> {
 
 /// A trait for vector types.
 pub trait Vector<T>: MetaData + ResizeOps
+    + FloatIndex<RangeFull, Output=[T]> + FloatIndex<Range<usize>>  + FloatIndex<RangeFrom<usize>, Output=[T]>
+    + FloatIndex<RangeTo<usize>> + FloatIndex<usize>
 where
     T: RealNumber,
 {
@@ -177,7 +206,7 @@ where
         }
 
         if len > self.alloc_len() {
-            r#try!(self.data.try_resize(len));
+            self.data.try_resize(len)?;
         }
 
         self.valid_len = len;
@@ -206,7 +235,7 @@ where
             Err(_) => {
                 let orig_len = self.len();
                 let mut temp = buffer.borrow(len);
-                temp[0..orig_len].clone_from_slice(&self[..]);
+                temp[0..orig_len].clone_from_slice(self.data(..));
                 temp.trade(&mut self.data);
                 self.valid_len = len;
                 Ok(())
@@ -272,7 +301,7 @@ where
     }
 }
 
-impl<S, T, N, D> Index<usize> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndex<usize> for DspVec<S, T, N, D>
 where
     S: ToSlice<T>,
     T: RealNumber,
@@ -281,7 +310,7 @@ where
 {
     type Output = T;
 
-    fn index(&self, index: usize) -> &T {
+    fn data(&self, index: usize) -> &T {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = &slice[0..len];
@@ -289,14 +318,14 @@ where
     }
 }
 
-impl<S, T, N, D> IndexMut<usize> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndexMut<usize> for DspVec<S, T, N, D>
 where
     S: ToSliceMut<T>,
     T: RealNumber,
     N: NumberSpace,
     D: Domain,
 {
-    fn index_mut(&mut self, index: usize) -> &mut T {
+    fn data_mut(&mut self, index: usize) -> &mut T {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = &mut slice[0..len];
@@ -304,7 +333,7 @@ where
     }
 }
 
-impl<S, T, N, D> Index<RangeFull> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndex<RangeFull> for DspVec<S, T, N, D>
 where
     S: ToSlice<T>,
     T: RealNumber,
@@ -313,28 +342,28 @@ where
 {
     type Output = [T];
 
-    fn index(&self, _index: RangeFull) -> &[T] {
+    fn data(&self, _index: RangeFull) -> &[T] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         &slice[0..len]
     }
 }
 
-impl<S, T, N, D> IndexMut<RangeFull> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndexMut<RangeFull> for DspVec<S, T, N, D>
 where
     S: ToSliceMut<T>,
     T: RealNumber,
     N: NumberSpace,
     D: Domain,
 {
-    fn index_mut(&mut self, _index: RangeFull) -> &mut [T] {
+    fn data_mut(&mut self, _index: RangeFull) -> &mut [T] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         &mut slice[0..len]
     }
 }
 
-impl<S, T, N, D> Index<RangeFrom<usize>> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndex<RangeFrom<usize>> for DspVec<S, T, N, D>
 where
     S: ToSlice<T>,
     T: RealNumber,
@@ -343,7 +372,7 @@ where
 {
     type Output = [T];
 
-    fn index(&self, index: RangeFrom<usize>) -> &[T] {
+    fn data(&self, index: RangeFrom<usize>) -> &[T] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = &slice[0..len];
@@ -351,14 +380,14 @@ where
     }
 }
 
-impl<S, T, N, D> IndexMut<RangeFrom<usize>> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndexMut<RangeFrom<usize>> for DspVec<S, T, N, D>
 where
     S: ToSliceMut<T>,
     T: RealNumber,
     N: NumberSpace,
     D: Domain,
 {
-    fn index_mut(&mut self, index: RangeFrom<usize>) -> &mut [T] {
+    fn data_mut(&mut self, index: RangeFrom<usize>) -> &mut [T] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = &mut slice[0..len];
@@ -366,7 +395,7 @@ where
     }
 }
 
-impl<S, T, N, D> Index<RangeTo<usize>> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndex<RangeTo<usize>> for DspVec<S, T, N, D>
 where
     S: ToSlice<T>,
     T: RealNumber,
@@ -375,7 +404,7 @@ where
 {
     type Output = [T];
 
-    fn index(&self, index: RangeTo<usize>) -> &[T] {
+    fn data(&self, index: RangeTo<usize>) -> &[T] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = &slice[0..len];
@@ -383,14 +412,14 @@ where
     }
 }
 
-impl<S, T, N, D> IndexMut<RangeTo<usize>> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndexMut<RangeTo<usize>> for DspVec<S, T, N, D>
 where
     S: ToSliceMut<T>,
     T: RealNumber,
     N: NumberSpace,
     D: Domain,
 {
-    fn index_mut(&mut self, index: RangeTo<usize>) -> &mut [T] {
+    fn data_mut(&mut self, index: RangeTo<usize>) -> &mut [T] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = &mut slice[0..len];
@@ -398,7 +427,7 @@ where
     }
 }
 
-impl<S, T, N, D> Index<Range<usize>> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndex<Range<usize>> for DspVec<S, T, N, D>
 where
     S: ToSlice<T>,
     T: RealNumber,
@@ -407,7 +436,7 @@ where
 {
     type Output = [T];
 
-    fn index(&self, index: Range<usize>) -> &[T] {
+    fn data(&self, index: Range<usize>) -> &[T] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = &slice[0..len];
@@ -415,14 +444,14 @@ where
     }
 }
 
-impl<S, T, N, D> IndexMut<Range<usize>> for DspVec<S, T, N, D>
+impl<S, T, N, D> FloatIndexMut<Range<usize>> for DspVec<S, T, N, D>
 where
     S: ToSliceMut<T>,
     T: RealNumber,
     N: NumberSpace,
     D: Domain,
 {
-    fn index_mut(&mut self, index: Range<usize>) -> &mut [T] {
+    fn data_mut(&mut self, index: Range<usize>) -> &mut [T] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = &mut slice[0..len];
@@ -439,7 +468,7 @@ where
 {
     type Output = Complex<T>;
 
-    fn complex(&self, index: usize) -> &Complex<T> {
+    fn datac(&self, index: usize) -> &Complex<T> {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = array_to_complex(&slice[0..len]);
@@ -454,7 +483,7 @@ where
     N: ComplexNumberSpace,
     D: Domain,
 {
-    fn complex_mut(&mut self, index: usize) -> &mut Complex<T> {
+    fn datac_mut(&mut self, index: usize) -> &mut Complex<T> {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = array_to_complex_mut(&mut slice[0..len]);
@@ -471,7 +500,7 @@ where
 {
     type Output = [Complex<T>];
 
-    fn complex(&self, _index: RangeFull) -> &[Complex<T>] {
+    fn datac(&self, _index: RangeFull) -> &[Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         array_to_complex(&slice[0..len])
@@ -485,7 +514,7 @@ where
     N: ComplexNumberSpace,
     D: Domain,
 {
-    fn complex_mut(&mut self, _index: RangeFull) -> &mut [Complex<T>] {
+    fn datac_mut(&mut self, _index: RangeFull) -> &mut [Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         array_to_complex_mut(&mut slice[0..len])
@@ -501,7 +530,7 @@ where
 {
     type Output = [Complex<T>];
 
-    fn complex(&self, index: RangeFrom<usize>) -> &[Complex<T>] {
+    fn datac(&self, index: RangeFrom<usize>) -> &[Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = array_to_complex(&slice[0..len]);
@@ -516,7 +545,7 @@ where
     N: ComplexNumberSpace,
     D: Domain,
 {
-    fn complex_mut(&mut self, index: RangeFrom<usize>) -> &mut [Complex<T>] {
+    fn datac_mut(&mut self, index: RangeFrom<usize>) -> &mut [Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = array_to_complex_mut(&mut slice[0..len]);
@@ -533,7 +562,7 @@ where
 {
     type Output = [Complex<T>];
 
-    fn complex(&self, index: RangeTo<usize>) -> &[Complex<T>] {
+    fn datac(&self, index: RangeTo<usize>) -> &[Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = array_to_complex(&slice[0..len]);
@@ -548,7 +577,7 @@ where
     N: ComplexNumberSpace,
     D: Domain,
 {
-    fn complex_mut(&mut self, index: RangeTo<usize>) -> &mut [Complex<T>] {
+    fn datac_mut(&mut self, index: RangeTo<usize>) -> &mut [Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = array_to_complex_mut(&mut slice[0..len]);
@@ -565,7 +594,7 @@ where
 {
     type Output = [Complex<T>];
 
-    fn complex(&self, index: Range<usize>) -> &[Complex<T>] {
+    fn datac(&self, index: Range<usize>) -> &[Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice();
         let slice = array_to_complex(&slice[0..len]);
@@ -580,7 +609,7 @@ where
     N: ComplexNumberSpace,
     D: Domain,
 {
-    fn complex_mut(&mut self, index: Range<usize>) -> &mut [Complex<T>] {
+    fn datac_mut(&mut self, index: Range<usize>) -> &mut [Complex<T>] {
         let len = self.valid_len;
         let slice = self.data.to_slice_mut();
         let slice = array_to_complex_mut(&mut slice[0..len]);
@@ -588,6 +617,246 @@ where
     }
 }
 
+impl<S, T, D> Index<usize> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = T;
+
+    fn index(&self, index: usize) -> &T {
+        self.data(index)
+    }
+}
+
+impl<S, T, D> IndexMut<usize> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: usize) -> &mut T {
+        self.data_mut(index)
+    }
+}
+
+impl<S, T, D> Index<RangeFull> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [T];
+
+    fn index(&self, index: RangeFull) -> &[T] {
+        self.data(index)
+    }
+}
+
+impl<S, T, D> IndexMut<RangeFull> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: RangeFull) -> &mut [T] {
+        self.data_mut(index)
+    }
+}
+
+impl<S, T, D> Index<RangeFrom<usize>> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [T];
+
+    fn index(&self, index: RangeFrom<usize>) -> &[T] {
+        self.data(index)
+    }
+}
+
+impl<S, T, D> IndexMut<RangeFrom<usize>> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: RangeFrom<usize>) -> &mut [T] {
+        self.data_mut(index)
+    }
+}
+
+impl<S, T, D> Index<RangeTo<usize>> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [T];
+
+    fn index(&self, index: RangeTo<usize>) -> &[T] {
+        self.data(index)
+    }
+}
+
+impl<S, T, D> IndexMut<RangeTo<usize>> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: RangeTo<usize>) -> &mut [T] {
+        self.data_mut(index)
+    }
+}
+
+impl<S, T, D> Index<Range<usize>> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [T];
+
+    fn index(&self, index: Range<usize>) -> &[T] {
+        self.data(index)
+    }
+}
+
+impl<S, T, D> IndexMut<Range<usize>> for DspVec<S, T, RealSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: Range<usize>) -> &mut [T] {
+        self.data_mut(index)
+    }
+}
+
+impl<S, T, D> Index<usize> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = Complex<T>;
+
+    fn index(&self, index: usize) -> &Complex<T> {
+        self.datac(index)
+    }
+}
+
+impl<S, T, D> IndexMut<usize> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: usize) -> &mut Complex<T> {
+        self.datac_mut(index)
+    }
+}
+
+impl<S, T, D> Index<RangeFull> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [Complex<T>];
+
+    fn index(&self, index: RangeFull) -> &[Complex<T>] {
+        self.datac(index)
+    }
+}
+
+impl<S, T, D> IndexMut<RangeFull> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: RangeFull) -> &mut [Complex<T>] {
+        self.datac_mut(index)
+    }
+}
+
+impl<S, T, D> Index<RangeFrom<usize>> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [Complex<T>];
+
+    fn index(&self, index: RangeFrom<usize>) -> &[Complex<T>] {
+        self.datac(index)
+    }
+}
+
+impl<S, T, D> IndexMut<RangeFrom<usize>> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: RangeFrom<usize>) -> &mut [Complex<T>] {
+        self.datac_mut(index)
+    }
+}
+
+impl<S, T, D> Index<RangeTo<usize>> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [Complex<T>];
+
+    fn index(&self, index: RangeTo<usize>) -> &[Complex<T>] {
+        self.datac(index)
+    }
+}
+
+impl<S, T, D> IndexMut<RangeTo<usize>> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: RangeTo<usize>) -> &mut [Complex<T>] {
+        self.datac_mut(index)
+    }
+}
+
+impl<S, T, D> Index<Range<usize>> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSlice<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    type Output = [Complex<T>];
+
+    fn index(&self, index: Range<usize>) -> &[Complex<T>] {
+        self.datac(index)
+    }
+}
+
+impl<S, T, D> IndexMut<Range<usize>> for DspVec<S, T, ComplexSpace, D>
+where
+    S: ToSliceMut<T>,
+    T: RealNumber,
+    D: Domain,
+{
+    fn index_mut(&mut self, index: Range<usize>) -> &mut [Complex<T>] {
+        self.datac_mut(index)
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::super::*;
@@ -626,13 +895,13 @@ mod tests {
     fn index_of_vec() {
         let vec = vec![1.0, 2.0, 3.0];
         let dsp = vec.to_real_time_vec();
-        assert_eq!(dsp[..], [1.0, 2.0, 3.0]);
+        assert_eq!(dsp.data(..), [1.0, 2.0, 3.0]);
     }
 
     #[test]
     fn index_of_slice() {
         let slice = [1.0, 5.0, 4.0];
         let dsp = slice.to_real_time_vec();
-        assert_eq!(dsp[..], [1.0, 5.0, 4.0]);
+        assert_eq!(dsp.data(..), [1.0, 5.0, 4.0]);
     }
 }
